@@ -124,6 +124,7 @@ readRAST6 <- function(vname, cat=NULL, ignore.stderr = FALSE,
 		    close(con)
 		    lres <- as.list(res)
 		    names(lres) <- colnames(res)
+		    lres <- lapply(lres, as.numeric)
 		    if (!is.numeric(lres$min) || 
 			!is.finite(as.double(lres$min))) 
 			    NODATA <- as.integer(999)
@@ -305,7 +306,7 @@ readBinGrid <- function(fname, colname=basename(fname),
 }
 
 writeRAST6 <- function(x, vname, zcol = 1, NODATA=NULL, 
-	ignore.stderr = FALSE, useGDAL=TRUE, overwrite=FALSE) {
+	ignore.stderr = FALSE, useGDAL=TRUE, overwrite=FALSE, flags=NULL) {
 
 
 	pid <- as.integer(round(runif(1, 1, 1000)))
@@ -328,6 +329,8 @@ writeRAST6 <- function(x, vname, zcol = 1, NODATA=NULL,
 	rtmpfl11 <- paste(rtmpfl1, fid, sep=.Platform$file.sep)
 	if (!is.numeric(x@data[[zcol]])) 
 		stop("only numeric columns may be exported")
+	if (overwrite && !("overwrite" %in% flags))
+		flags <- c(flags, "overwrite")
 #	cmd <- paste("g.version", .addexe(), sep="")
 #	tull <- ifelse(.Platform$OS.type=="windows",
 #		Gver <- system(cmd, intern=TRUE), 
@@ -363,8 +366,6 @@ writeRAST6 <- function(x, vname, zcol = 1, NODATA=NULL,
 #	    tull <- ifelse(.Platform$OS.type == "windows", 
 #		system(cmd), system(cmd, ignore.stderr=ignore.stderr))
 
-	    if (overwrite) flags <- "overwrite"
-            else flags <- NULL
 	    execGRASS("r.in.gdal", flags=flags, parameters=list(input=gtmpfl11,
 		output=vname), ignore.stderr=ignore.stderr)
 
@@ -382,9 +383,9 @@ writeRAST6 <- function(x, vname, zcol = 1, NODATA=NULL,
 #	    tull <- ifelse(.Platform$OS.type == "windows", 
 #		system(cmd), system(cmd, ignore.stderr=ignore.stderr))
 
-	    if (overwrite) flags <- c(res$flag, "overwrite")
-		
-	    execGRASS("r.in.bin", flags=flags, parameters=list(input=gtmpfl11,
+	    flags <- c(res$flag, flags)
+	    
+	    execGRASS("r.in.bin", flags=res$flag, parameters=list(input=gtmpfl11,
 		output=vname, bytes=as.integer(res$bytes), 
 		north=as.numeric(res$north), south=as.numeric(res$south), 
 		east=as.numeric(res$east), west=as.numeric(res$west), 
